@@ -1,4 +1,5 @@
-/* config.h: configuration definitions
+/*
+ * config.h: configuration definitions
  *
  * Copyright (c) 1989 James E. Wilson
  *
@@ -7,29 +8,18 @@
  * included in all such copies.
  */
 
-/* Person to bother if something goes wrong.
- * Recompile files.c and misc2.c if these change.
- */
+#ifndef _CONFIG_H_
+#define _CONFIG_H_
+
+/* Person to bother if something goes wrong. */
 
 #define WIZARD	"root"
 
-/* There's a bug that results in invisible monsters for some reason.  I have a
- * workaround that may fix this, but it is a HACK and may result in other
- * problems, as I have not tested it enough.  Comment out the
- * "#define GROSS_HACK" to disable this.  (this is in creature.c at line 73)
- ******
- * This should no longer be needed for Angband 2.6, but it doesn't hurt to
- * leave it in. -CWS
- */
-
-#define GROSS_HACK
-
-
 /* Other miscellaneous defines that can be configured as the local maintainer
  * wishes.
  */
 
-#define SET_UID		         /* define on multi-user systems                 */
+#define SET_UID		     /* define on multi-user systems                 */
 #undef CHECKHOURS            /* define if checking the 'hours' file          */
 #define ALLOW_FIDDLING       /* Allow the players to copy save files         */
 #define ALLOW_SCORE          /* Allow the user to check his score (v-key)    */
@@ -37,9 +27,9 @@
 #define ALLOW_CHECK_UNIQUES  /* Allow player to check (dead) unique monsters */
 #define TARGET               /* Enable targeting mode                        */
 #define AUTOROLLER           /* Allow autorolling of characters              */
-#undef NICE		             /* Be nice to other users during autorolling    */
-#define SATISFY_HUNGER		 /* Do 'satisfy hunger' rather then 'create food'
-								to reduce the tedium for handling food. -CWS */
+#undef NICE	             /* Be nice to other users during autorolling    */
+#define SATISFY_HUNGER	     /* Do 'satisfy hunger' rather then 'create food'
+				to reduce the tedium for handling food. -CWS */
 
 
 /*****************************************************
@@ -50,6 +40,9 @@
  * paths directly into Angband.  Define NEW_FILEPATHS to use the new,
  * studly method (which uses the ANGBAND_PATH environment variable to
  * look for the files).                                         [cjh]
+ *
+ * Note that some systems (SunOS/Solaris, I believe) have problems with the
+ * NEW_FILEPATHS option, and hence must use the older version.
  */
 
 #undef  OLD_FILEPATHS
@@ -67,11 +60,6 @@
 
 #ifdef OLD_FILEPATHS
 
-/* Try to fix filename inclusion in a portable fashion.
- * John Whitly@cs.Buffalo.edu says this works under gcc 2.5.5, but my
- * older version chokes.  I dunno. -CWS
- */
-
 #ifdef __STDC__
 #define LIBDIR(FILE) "/User/games/lib/angband/" #FILE
 #else
@@ -96,70 +84,99 @@
 #define ANGBAND_SAV       LIBDIR(save)
 #endif /* OLD_FILEPATHS */
 
+/*** End of Pathname code ***/
 
-/* this sets the default user interface
+
+/* This sets the default user interface:
+ *
  * to use the original key bindings (keypad for movement) set ROGUE_LIKE
  * to FALSE, to use the rogue-like key bindings (vi style movement)
  * set ROGUE_LIKE to TRUE
- * if you change this, you only need to recompile main.c */
+ */
 
 #define ROGUE_LIKE TRUE
 
 
-/* for the AFS distributed file system, define this to ensure that
-   the program is secure with respect to the setuid code, this prohibits
-   inferior shells, also does not relinquish setuid priviledges at the start,
-   but instead calls the AFS library routines bePlayer(), beGames(),
-   and Authenticate() */
+/* For the AFS distributed file system, define this to ensure that
+ * the program is secure with respect to the setuid code, this prohibits
+ * inferior shells, also does not relinquish setuid priviledges at the start,
+ * but instead calls the AFS library routines bePlayer(), beGames(),
+ * and Authenticate().
+ */
 
 /* #define SECURE */
 
-
-/* Note that any reasonably modern compiler does better when you *don't* use
- * "register".  I've hacked it out here because I don't want to change every
- * arg list in the game.  You might want to undo this if your compiler sucks.
- *                   -CWS
+/*
+ * Specific system declarations.
+ *
+ * You might have to uncomment a #define below if you have one of the
+ * operating systems described below.  If anyone can provide me with the
+ * macros which are guaranteed to be provided by all of the compilers in use,
+ * then I can remove that declaration and make everyone's life a little easier.
  */
 
-#define register
+/* if you are compiling on a Solaris 2 / SunOS 5.x machine, define this: */
 
+/* #ifndef SOLARIS
+#define SOLARIS
+#endif */
 
-/* this allows intelligent compilers to do better, as they know more
- * about how certain functions behave -CWS */
-
-#if !(defined(__GNUC__) || defined(__STDC__))
-#define const
+#if defined(SOLARIS)
+# ifndef SYS_V
+#  define SYS_V
+# endif /* SYS_V */
+# include <netdb.h>
 #endif
 
+#ifdef __bsdi__
+#define POSIX
+#endif
 
-/* no system definitions are needed for 4.3BSD, SUN OS, DG/UX */
+/* If you are compiling on an ultrix/4.2BSD/Dynix/etc. version of UNIX,
+ * define this:
+ */
 
-/* if you are compiling on an ultrix/4.2BSD/Dynix/etc. version of UNIX,
-   define this, not needed for SUNs */
 /* #ifndef ultrix
 #define ultrix
 #endif */
 
-#if defined(SOLARIS)
-#define SYS_V
-#include <netdb.h>
-#endif
-
-/* if you are compiling on a SYS V version of UNIX, define this */
+/* If you are compiling on a SYS V version of UNIX, define this */
 /* #define SYS_V */
 
-/* if you are compiling on a SYS III version of UNIX, define this */
+/* If you are compiling on a SYS III version of UNIX, define this */
 /* #define SYS_III */
 
-/* if you are compiling on an ATARI ST with Mark Williams C, define this */
+/* If you are compiling on an ATARI ST with Mark Williams C, define this */
 /* #define ATARIST_MWC */
 
-/* if you are compiling on a Macintosh with MPW C 3.0, define this */
+/* If you are compiling on a Macintosh with MPW C 3.0, define this */
 /* #define MAC */
 
-/* if you are compiling on a HPUX version of UNIX, define this */
+/* If you are compiling on a HPUX version of UNIX, define this */
 /* #define HPUX */
 
+/* If you are compiling on an AIX version of UNIX define this */
+/* #define AIX */
+
+/* if you are compiling on an SGI running IRIX, define this */
+/* #define SGI */
+
+#ifdef AIX
+# ifndef SYS_V
+#  define SYS_V
+# endif
+#endif
+
+/* If your system does not provide the bzero() call, uncomment the following
+ * #define.  -CWS 
+ */
+
+/* #define NEEDS_BZERO */
+
+#ifdef NEEDS_BZERO
+#define bzero my_bzero
+#endif
+
 /****************************************************************************
  * System dependent defines follow, you should not need to change anything  *
  * below (if you have a supported system).  If you run into problems during *
@@ -178,7 +195,7 @@
 
 #if defined(ultrix) || defined(SYS_V) || defined(SYS_III) \
  || defined(__MINT__) || defined(HPUX) || defined(unix) \
- || defined(BSD)
+ || defined(BSD) || defined(AMIGA)
 #  define PATH_SEP "/"
 #else
 #  if defined(__EMX__) || defined(MSDOS) || defined(OS2) || defined(WINNT) \
@@ -201,16 +218,48 @@
  * you're still in luck, as we now provide one.  -CWS
  */
 
-#if defined (NeXT) || defined(HPUX) || defined(ultrix) \
-|| defined(NCR3K) || defined(linux) || defined(ibm032) \
-|| defined(__386BSD__) || defined(SOLARIS) || defined (__osf__)
+#if defined (NeXT) || defined(HPUX) || defined(ultrix) || defined(NCR3K) \
+|| defined(linux) || defined(ibm032) || defined(__386BSD__) || \
+defined (__osf__) || defined(SOLARIS) || defined(SGI)
+
 #define stricmp strcasecmp
-#else
-/* Let's make this work on systems lacking a such a routine. */
+
+#else /* Let's make this work on systems lacking a such a routine. */
+
 #define stricmp my_stricmp
 #define NEEDS_STRICMP
+
+#endif /* has strcasecomp */
+
+
+/* fix systems lacking usleep() -CWS 
+ *
+ * Note that Solaris 2.x users without the BSD compatibility kit need to
+ * define this as well.
+ */
+
+#if defined(HPUX) || defined(ultrix) || defined(SOLARIS) || defined(SGI)
+#define NEEDS_USLEEP
 #endif
 
+#ifdef NEEDS_USLEEP
+#define usleep microsleep
+
+#ifdef __STDC__
+int microsleep(unsigned long);
+#else
+int microsleep();
+#endif /* __STDC__ */
+
+#endif
+
+/* This allows intelligent compilers to do better, as they know more
+ * about how certain functions behave. -CWS
+ */
+
+#if !(defined(__GNUC__) || defined(__STDC__))
+#define const
+#endif
 
 /* this takes care of almost all "implicit declaration" warnings -CWS */
 
@@ -227,28 +276,6 @@
 #endif
 
 
-/* fix systems lacking usleep() -CWS 
- *
- * Note that Solaris 2.x users without the BSD compatibilty kit need to
- * define this as well.
- */
-
-#if defined(HPUX) || defined(ultrix)
-#define NEEDS_USLEEP
-#endif
-
-#ifdef NEEDS_USLEEP
-#define usleep microsleep
-
-#ifdef __STDC__
-int microsleep(unsigned long);
-#else
-int microsleep();
-#endif /* __STDC__ */
-
-#endif
-
-
 /* substitute strchr for index on USG versions of UNIX */
 #if defined(SYS_V) || defined(MSDOS) || defined(MAC)
 #define index strchr
@@ -258,16 +285,11 @@ int microsleep();
 char *index();
 #endif
 
-#if defined(SYS_III) || defined(SYS_V) || defined(MSDOS) || defined(MAC) || defined(HPUX)
-#ifndef USG
-#define USG
-#endif
-#endif
-
-#if defined(ATARIST_MWC) || defined (__MINT__)
-#ifndef USG
-#define USG
-#endif
+#if defined(SYS_III) || defined(SYS_V) || defined(MSDOS) || defined(MAC) || \
+defined(HPUX) || defined(ATARIST_MWC) || defined (__MINT__) || defined(SGI)
+# ifndef USG
+#  define USG
+# endif
 #endif
 
 /* Pyramid runs 4.2BSD-like UNIX version */
@@ -275,16 +297,12 @@ char *index();
 #define ultrix
 #endif
 
-#ifdef MSDOS
-#define register      /* MSC 4.0 still has a problem with register bugs ... */
-#endif
-
 #ifdef MAC
-#ifdef RSRC
-#define MACRSRC		/* i.e., we're building the resources */
-#else
-#define MACGAME		/* i.e., we're building the game */
-#endif
+# ifdef RSRC
+#  define MACRSRC     /* i.e., we're building the resources */
+# else
+#  define MACGAME     /* i.e., we're building the game */
+# endif
 #endif
 
 #ifdef MAC
@@ -313,48 +331,4 @@ extern int PlayerUID;
 #define geteuid() PlayerUID
 #endif
 
-
-/*****************************************************************************/
-
-/* Here's some functions that've been macroized rather than being called
- * from everywhere.  They're short enough so that inlining them will probably
- * result in a smaller executable, and speed things up, to boot. -CWS
- */
-
-#define MY_MAX(a,b) ((a) > (b) ? (a) : (b))
-#define MY_MIN(a,b) ((a) < (b) ? (a) : (b))
-
-
-/* Checks a co-ordinate for in bounds status		-RAK-	*/
-
-#define in_bounds(y, x) \
-   ((((y) > 0) && ((y) < cur_height-1) && ((x) > 0) && ((x) < cur_width-1)) ? \
-    (TRUE) : (FALSE))
-
-
-/* Checks if we can see this point (includes map edges) -CWS */
-#define in_bounds2(y, x) \
-   ((((y) >= 0) && ((y) < cur_height) && ((x) >= 0) && ((x) < cur_width)) ? \
-    (TRUE) : (FALSE))
-
-
-/* Tests a given point to see if it is within the screen -RAK-
- * boundaries.
- */
-
-#define panel_contains(y, x) \
-  ((((y) >= panel_row_min) && ((y) <= panel_row_max) && \
-    ((x) >= panel_col_min) && ((x) <= panel_col_max)) ? (TRUE) : (FALSE))
-
-
-/* Generates a random integer X where 1<=X<=MAXVAL	-RAK-	*/
-
-#define randint(maxval) (((maxval) < 1) ? (1) : ((random() % (maxval)) + 1))
-
-/* You would think that most compilers can do an integral abs() quickly,
- * wouldn't you?  Nope.  [But fabs is a lot worse on most machines!] -CWS
- */
-
-#define MY_ABS(x) (((x)<0) ? (-x) : (x))
-
-/*****************************************************************************/
+#endif /* _CONFIG_H_ */
