@@ -8,10 +8,7 @@
  * included in all such copies. 
  */
 
-#include "constant.h"
-#include "config.h"
-#include "types.h"
-#include "externs.h"
+#include "angband.h"
 
 #ifdef USG
 #ifndef ATARIST_MWC
@@ -48,10 +45,10 @@ int ch;
       case 'E':
       case 'I':
       case 'O':
-      case 'U':
-	return (TRUE);
+      case 'U':        
+        return (TRUE);
       default:
-	return (FALSE);
+        return (FALSE);
     }
 }
 
