@@ -1,4 +1,4 @@
-/* externs.h: declarations for global variables and initialized data
+ /* externs.h: declarations for global variables and initialized data
 
    Copyright (c) 1989 James E. Wilson, Robert A. Koeneke
 
@@ -6,27 +6,16 @@
    not for profit purposes provided that this copyright and statement are
    included in all such copies. */
 
-#define get_Yn get_check
+#ifndef _EXTERNS_H_
+#define _EXTERNS_H_
 
 #include <stdio.h>
 
-/* many systems don't define these anywhere */
-#if defined(USG) || defined(DGUX) || defined(atarist)
-#if !(defined(HPUX) || defined(linux))
-extern int sprintf();
-#endif
-#else
-#if !(defined(MSDOS) || defined(NeXT) || defined(ultrix) || defined(linux) \
-|| defined(__386BSD__) || defined(SOLARIS))
-extern char *sprintf();
-#endif
-#endif
-
 #ifndef MSDOS
 extern int errno;
 #endif
 
-extern char *copyright[5];
+extern const char *copyright[5];
 
 extern int player_uid;
 extern int NO_SAVE;
@@ -35,33 +24,37 @@ extern int NO_SAVE;
    within creatures() via place_monster() and summon_monster() */
 extern int hack_monptr;
 
-extern int16 log_index;			/* Index to log file. -CJS- */
+extern int16 log_index;		/* Index to log file. -CJS- */
 extern vtype died_from;
-extern vtype savefile;			/* The save file. -CJS- */
+extern vtype savefile;		/* The save file. -CJS- */
 
 /* These are options, set with set_options command -CJS- */
 extern int rogue_like_commands;
-extern int find_cut;			/* Cut corners on a run */
-extern int find_examine;		/* Check corners on a run */
-extern int find_prself;			/* Print yourself on a run (slower) */
-extern int find_bound;			/* Stop run when the map shifts */
+extern int find_cut;		/* Cut corners on a run */
+extern int find_examine;	/* Check corners on a run */
+extern int find_prself;		/* Print yourself on a run (slower) */
+extern int find_bound;		/* Stop run when the map shifts */
 extern int prompt_carry_flag;	/* auto-pickupobjects */
+extern int always_throw;	/* Never confirm -Abby- */
 extern int show_weight_flag;	/* Display weights in inventory */
-extern int show_equip_weight_flag;	/* Display weights in equip list -CWS */
-extern int highlight_seams;		/* Highlight magma and quartz */
+extern int show_equip_weight_flag;  /* Display weights in equip list -CWS */
+extern int highlight_seams;	/* Highlight magma and quartz */
 extern int find_ignore_doors;	/* Run through open doors */
-extern int delay_spd;			/* 1-10 for delays */
-extern int hitpoint_warn;		/* Low hitpoint warning */
-extern int peek;				/* should we display additional msgs */
+extern int delay_spd;		/* 1-10 for delays */
+extern int hitpoint_warn;	/* Low hitpoint warning */
+extern int peek;		/* should we display additional msgs */
 extern int carry_query_flag;	/* ask whether to pick something up */
-extern int is_home;				/* are we in our home? */
-extern int in_store_flag;		/* Don't redisplay light in stores -DGK */
+extern int is_home;		/* are we in our home? */
+extern int in_store_flag;	/* Don't redisplay light in stores -DGK */
 extern int plain_descriptions;	/* don't add color to any obj -CWS */
-extern int no_haggle_flag;		/* does the player have to haggle? -CWS */
-extern int quick_messages;		/* do quick messages -CWS */
-extern int equippy_chars;		/* do equipment characters -CWS */
-extern int coin_type;			/* remember Creeping _xxx_ coin type -CWS */
-extern int opening_chest;		/* do not generate another chest -CWS */
+extern int no_haggle_flag;	/* does the player have to haggle? -CWS */
+extern int quick_messages;	/* do quick messages -CWS */
+extern int equippy_chars;	/* do equipment characters -CWS */
+extern int coin_type;		/* remember Creeping _xxx_ coin type -CWS */
+extern int opening_chest;	/* do not generate another chest -CWS */
+extern int ring_bell;		/* ring bell on error -Abby- */
+extern int shuffle_store_owners; /* can have store owners randomly change -CWS */
+extern int new_screen_layout;   /* Use the new screen layout -CWS */
 
 /* Unique artifact weapon flags */
 extern int32 GROND, RINGIL, AEGLOS, ARUNRUTH, MORMEGIL, ANGRIST, GURTHANG,
@@ -89,56 +82,56 @@ extern int quests[MAX_QUESTS];
 
 /* global flags */
 extern int unfelt;
-extern int in_store_flag;		/* flag so equippy chars work right -DGK */
-extern int good_item_flag;		/* True if an artifact has been created... */
+extern int in_store_flag;	/* flag so equippy chars work right -DGK */
+extern int good_item_flag;	/* True if an artifact has been created... */
 extern int LOAD;
-extern int new_level_flag;		/* Next level when true  */
-extern int teleport_flag;		/* Handle teleport traps  */
-extern int eof_flag;			/* Used to handle eof/HANGUP */
-extern int player_light;		/* Player carrying light */
-extern int light_rad,old_rad;           /* Light radius */
-extern int find_flag;        	/* Used in MORIA	      */
-extern int free_turn_flag;		/* Used in MORIA	      */
-extern int weapon_heavy;		/* Flag if the weapon too heavy -CJS- */
-extern int pack_heavy;			/* Flag if the pack too heavy -CJS- */
-extern char doing_inven;		/* Track inventory commands */
-extern int screen_change;		/* Screen changes (used in inven_commands) */
+extern int new_level_flag;	/* Next level when true	 */
+extern int teleport_flag;	/* Handle teleport traps  */
+extern int eof_flag;		/* Used to handle eof/HANGUP */
+extern int player_light;	/* Player carrying light */
+extern int light_rad,old_rad;		/* Light radius */
+extern int find_flag;		/* Used in MORIA	  */
+extern int free_turn_flag;	/* Used in MORIA	  */
+extern int weapon_heavy;	/* Flag if the weapon too heavy -CJS- */
+extern int pack_heavy;		/* Flag if the pack too heavy -CJS- */
+extern char doing_inven;	/* Track inventory commands */
+extern int screen_change;	/* Screen changes (used in inven_commands) */
 extern int be_nasty;
 extern int monster_is_afraid;	/* redo monster fear messages -CWS */
 
-extern int character_generated;	/* don't save score until char gen finished */
-extern int character_saved;		/* prevents save on kill after save_char() */
-extern int feeling;				/* level feeling */
-extern int highscore_fd;		/* High score file descriptor */
-extern int command_count;		/* Repetition of commands. -CJS- */
-extern int default_dir;			/* Use last direction in repeated commands */
-extern int16 noscore;			/* Don't score this game. -CJS- */
-extern int32u randes_seed;		/* For encoding colors */
-extern int32u town_seed;		/* Seed for town generation */
-extern char *old_state;			/* state array initialized by time -CWS */
-extern char *dummy_state;		/* dummy state array so that town/colors look
-                                 * the same -CWS */
+extern int character_generated; /* don't save score until char gen finished */
+extern int character_saved;	/* prevents save on kill after save_char() */
+extern int feeling;		/* level feeling */
+extern int highscore_fd;	/* High score file descriptor */
+extern int command_count;	/* Repetition of commands. -CJS- */
+extern int default_dir;		/* Use last direction in repeated commands */
+extern int16 noscore;		/* Don't score this game. -CJS- */
+extern int32u randes_seed;	/* For encoding colors */
+extern int32u town_seed;	/* Seed for town generation */
+extern char *old_state;		/* state array initialized by time -CWS */
+extern char *dummy_state;	/* dummy state array so that town/colors look
+				 * the same -CWS */
 
-extern int16 dun_level;         /* Cur dungeon level   */
-extern int16 object_level;		/* used to generate objects -CWS */
-extern int16 missile_ctr;		/* Counter for missiles */
-extern int msg_flag;			/* Set with first msg  */
-extern vtype old_msg[MAX_SAVE_MSG];	/* Last messages -CJS- */
-extern int16 last_msg;			/* Where in the array is the last */
-extern int death;				/* True if died	      */
-extern int32 turn;				/* Cur turn of game    */
-extern int32 old_turn;			/* last turn feeling was felt */
-extern int wizard;				/* Wizard flag	      */
+extern int16 dun_level;		/* Cur dungeon level   */
+extern int object_level;	/* used to generate objects -CWS */
+extern int16 missile_ctr;	/* Counter for missiles */
+extern int msg_flag;		/* Set with first msg  */
+extern vtype old_msg[MAX_SAVE_MSG]; /* Last messages -CJS- */
+extern int16 last_msg;		/* Where in the array is the last */
+extern int death;		/* True if died	      */
+extern int32 turn;		/* Cur turn of game    */
+extern int32 old_turn;		/* last turn feeling was felt */
+extern int wizard;		/* Wizard flag	      */
 extern int to_be_wizard;
-extern int16 panic_save;		/* this is true if playing from a panic save */
+extern int16 panic_save;	/* this is true if playing from a panic save */
 
 extern int wait_for_more;
 
 extern char days[7][29];
-extern int closing_flag;		/* Used for closing   */
+extern int closing_flag;	/* Used for closing   */
 
-extern int16 cur_height, cur_width;	/* Cur dungeon size    */
-/*  Following are calculated from max dungeon sizes		*/
+extern int16 cur_height, cur_width; /* Cur dungeon size	   */
+/*  Following are calculated from max dungeon sizes	*/
 extern int16 max_panel_rows, max_panel_cols;
 extern int panel_row, panel_col;
 extern int panel_row_min, panel_row_max;
@@ -153,21 +146,21 @@ extern int16u target_row;
 extern int16u target_mon;
 #endif
 
-/*  Following are all floor definitions				*/
+/*  Following are all floor definitions		    */
 #ifdef MAC
 extern cave_type (*cave)[MAX_WIDTH];
 #else
 extern cave_type cave[MAX_HEIGHT][MAX_WIDTH];
 #endif
 
-/* Following are player variables				*/
+/* Following are player variables		*/
 extern player_type py;
 #ifdef MACGAME
-extern char *(*player_title)[MAX_PLAYER_LEVEL];
+extern const char *(*player_title)[MAX_PLAYER_LEVEL];
 extern race_type *race;
 extern background_type *background;
 #else
-extern char *player_title[MAX_CLASS][MAX_PLAYER_LEVEL];
+extern const char *player_title[MAX_CLASS][MAX_PLAYER_LEVEL];
 extern race_type race[MAX_RACES];
 extern background_type background[MAX_BACKGROUND];
 #endif
@@ -194,17 +187,17 @@ extern spell_type magic_spell[MAX_CLASS-1][63];
 extern const char *spell_names[127];
 extern int32u spell_learned;	/* Bit field for spells learnt -CJS- */
 extern int32u spell_learned2;	/* Bit field for spells learnt -CJS- */
-extern int32u spell_worked;		/* Bit field for spells tried -CJS- */
+extern int32u spell_worked;	/* Bit field for spells tried -CJS- */
 extern int32u spell_worked2;	/* Bit field for spells tried -CJS- */
 extern int32u spell_forgotten;	/* Bit field for spells forgotten -JEW- */
-extern int32u spell_forgotten2;	/* Bit field for spells forgotten -JEW- */
+extern int32u spell_forgotten2; /* Bit field for spells forgotten -JEW- */
 extern int8u spell_order[64];	/* remember order that spells are learned in */
 extern int32u spellmasks[MAX_CLASS][2];
 /* used to check if player knows all spells knowable to him -CFT */
 extern int16u player_init[MAX_CLASS][5];
 extern int16 total_winner;
 
-/* Following are store definitions				*/
+/* Following are store definitions		*/
 #ifdef MACGAME
 extern owner_type *owners;
 #else
@@ -220,7 +213,7 @@ extern int16u store_choice[MAX_STORES][STORE_CHOICES];
 extern int (*store_buy[MAX_STORES])();
 #endif
 
-/* Following are treasure arrays	and variables			*/
+/* Following are treasure arrays    and variables	    */
 #ifdef MACGAME
 extern treasure_type *object_list;
 #else
@@ -232,12 +225,12 @@ extern inven_type t_list[MAX_TALLOC];
 extern inven_type inventory[INVEN_ARRAY_SIZE];
 extern const char *special_names[SN_ARRAY_SIZE];
 extern int16 sorted_objects[MAX_DUNGEON_OBJ];
-extern int16 inven_ctr;			/* Total different obj's	*/
-extern int16 inven_weight;		/* Cur carried weight	*/
-extern int16 equip_ctr;			/* Cur equipment ctr	*/
-extern int16 tcptr;				/* Cur treasure heap ptr	*/
+extern int16 inven_ctr;		/* Total different obj's    */
+extern int16 inven_weight;	/* Cur carried weight	*/
+extern int16 equip_ctr;		/* Cur equipment ctr	*/
+extern int16 tcptr;		/* Cur treasure heap ptr    */
 
-/* Following are creature arrays and variables			*/
+/* Following are creature arrays and variables		*/
 #ifdef MACGAME
 extern creature_type *c_list;
 #else
@@ -250,13 +243,13 @@ extern m_attack_type monster_attacks[N_MONS_ATTS];
 #ifdef MAC
 extern recall_type *c_recall;
 #else
-extern recall_type c_recall[MAX_CREATURES];	/* Monster memories. -CJS- */
+extern recall_type c_recall[MAX_CREATURES]; /* Monster memories. -CJS- */
 #endif
-extern monster_type blank_monster; /* Blank monster values	*/
-extern int16 mfptr;				   /* Cur free monster ptr	*/
-extern int16 mon_tot_mult;		   /* # of repro's of creature	*/
+extern monster_type blank_monster; /* Blank monster values  */
+extern int16 mfptr;		   /* Cur free monster ptr  */
+extern int16 mon_tot_mult;	   /* # of repro's of creature	*/
 
-/* Following are arrays for descriptive pieces			*/
+/* Following are arrays for descriptive pieces		*/
 #ifdef MACGAME
 extern const char **colors;
 extern const char **mushrooms;
@@ -283,36 +276,36 @@ extern int16u normal_table[NORMAL_TABLE_SIZE];
 /* Since these get modified, macrsrc.c must be able to access them */
 /* Otherwise, game cannot be made restartable */
 /* dungeon.c */
-extern char last_command;		/* Memory of previous command. */
+extern char last_command;	/* Memory of previous command. */
 /* moria1.c */
 /* Track if temporary light about player.  */
 extern int light_flag;
 
 #ifdef MSDOS
 extern int8u	floorsym, wallsym;
-extern int	ansi, saveprompt;
-extern char	moriatop[], moriasav[];
+extern int  ansi, saveprompt;
+extern char moriatop[], moriasav[];
 #endif
 
 
 /* If you use NEW_FILEPATHS, we need these externs; if you use OLD_FILEPATHS */
-/* these are #define'd to something, so they aren't variables.         [cjh] */
+/* these are #define'd to something, so they aren't variables.	       [cjh] */
 #ifdef NEW_FILEPATHS
-extern char *ANGBAND_TST;		/* was LIBDIR(test)					*/
-extern char *ANGBAND_HOU;		/* was LIBDIR(files/hours)			*/
-extern char *ANGBAND_MOR;		/* was LIBDIR(files/news)			*/
-extern char *ANGBAND_TOP;		/* was LIBDIR(files/newscores)		*/
-extern char *ANGBAND_BONES;		/* was LIBDIR(bones)				*/
-extern char *ANGBAND_HELP;		/* was LIBDIR(files/roglcmds.hlp)	*/
-extern char *ANGBAND_ORIG_HELP;	/* was LIBDIR(files/origcmds.hlp)	*/
-extern char *ANGBAND_WIZ_HELP;	/* was LIBDIR(files/rwizcmds.hlp)	*/
-extern char *ANGBAND_OWIZ_HELP;	/* was LIBDIR(files/owizcmds.hlp)	*/
-extern char *ANGBAND_WELCOME;	/* was LIBDIR(files/welcome.hlp)	*/
-extern char *ANGBAND_LOG;		/* was LIBDIR(files/ANGBAND.log)	*/
-extern char *ANGBAND_VER;		/* was LIBDIR(files/version.hlp)	*/
-extern char *ANGBAND_LOAD;		/* was LIBDIR(files/loadcheck)		*/
-extern char *ANGBAND_WIZ;		/* was LIBDIR(files/wizards)		*/
-extern char *ANGBAND_SAV;		/* was LIBDIR(save)					*/
+extern char *ANGBAND_TST;	/* was LIBDIR(test)		    */
+extern char *ANGBAND_HOU;	/* was LIBDIR(files/hours)	    */
+extern char *ANGBAND_MOR;	/* was LIBDIR(files/news)	    */
+extern char *ANGBAND_TOP;	/* was LIBDIR(files/newscores)	    */
+extern char *ANGBAND_BONES;	/* was LIBDIR(bones)		    */
+extern char *ANGBAND_HELP;	/* was LIBDIR(files/roglcmds.hlp)   */
+extern char *ANGBAND_ORIG_HELP; /* was LIBDIR(files/origcmds.hlp)   */
+extern char *ANGBAND_WIZ_HELP;	/* was LIBDIR(files/rwizcmds.hlp)   */
+extern char *ANGBAND_OWIZ_HELP; /* was LIBDIR(files/owizcmds.hlp)   */
+extern char *ANGBAND_WELCOME;	/* was LIBDIR(files/welcome.hlp)    */
+extern char *ANGBAND_LOG;	/* was LIBDIR(files/ANGBAND.log)    */
+extern char *ANGBAND_VER;	/* was LIBDIR(files/version.hlp)    */
+extern char *ANGBAND_LOAD;	/* was LIBDIR(files/loadcheck)	    */
+extern char *ANGBAND_WIZ;	/* was LIBDIR(files/wizards)	    */
+extern char *ANGBAND_SAV;	/* was LIBDIR(save)		    */
 #endif /* NEW_FILEPATHS */
 
 
@@ -365,7 +358,6 @@ void dungeon(void);
 int special_check(inven_type *);
 int is_quest(int);
 void rerate(void);
-int ruin_stat(int);
 
 /* eat.c */
 void eat(void);
@@ -514,7 +506,7 @@ void prt_winner(void);
 int16u modify_stat(int, int);
 void set_use_stat(int);
 int inc_stat(int);
-int dec_stat(int);
+int dec_stat(int, int, int);
 int res_stat(int);
 void bst_stat(int, int);
 int tohit_adj(void);
@@ -669,7 +661,7 @@ int roff_recall(int);
 /* random.c */
 #if !(defined(linux) || defined(__osf__))
 long random(void);
-#if !(defined(__MINT__) || defined(__386BSD__))
+#if !(defined(__MINT__) || defined(__386BSD__) || defined(AMIGA) || defined(__bsdi__))
 void srandom(int);
 #endif
 char *initstate(unsigned int, char *, int);
@@ -840,7 +832,7 @@ void enter_store(int);
 void init_files(void);
 int _new_log(void);
 
-#ifdef unix
+#if defined(unix) || defined(AMIGA)
 /* unix.c */
 int check_input(int);
 #if 0
@@ -920,7 +912,6 @@ void dungeon();
 int special_check();
 int is_quest();
 void rerate();
-int ruin_stat();
 
 /* eat.c */
 void eat();
@@ -1166,9 +1157,9 @@ void disarm_trap();
 void look();
 void throw_object();
 void bash();
-void target();					/* target fns stolen from Morgul -CFT */
-int at_target();				/* target fns stolen from Morgul -CFT */
-void mmove2();					/* target fns stolen from Morgul -CFT */
+void target();			/* target fns stolen from Morgul -CFT */
+int at_target();		/* target fns stolen from Morgul -CFT */
+void mmove2();			/* target fns stolen from Morgul -CFT */
 
 #ifdef MSDOS
 /* ms_misc.c */
@@ -1323,7 +1314,7 @@ int enchant();
 int remove_curse();
 int restore_level();
 void self_knowledge();
-char *pain_message()
+char *pain_message();
 void line_spell();
 
 /* staffs.c */
@@ -1389,4 +1380,7 @@ void artifact_check();
 void artifact_check_no_file();
 void check_uniques();
 int is_wizard();
-#endif      /* __STDC__ */
+
+#endif /* __STDC__ */
+
+#endif /* _EXTERNS_H_ */
