@@ -10,11 +10,8 @@
 
 #include <ctype.h>
 
-#include "constant.h"
+#include "angband.h"
 #include "monster.h"
-#include "config.h"
-#include "types.h"
-#include "externs.h"
 
 #ifdef USG
 #ifndef ATARIST_MWC
@@ -131,6 +128,7 @@ int y, x;
 		    else
 			msg_print("You are unaffected by the poison.");
 		}
+		take_hit(dam, tmp);
 	    } /* no ffall */
 	}
 	break;
@@ -153,7 +151,7 @@ int y, x;
       case 7:			   /* STR Dart */
 	if (test_hit(125, 0, 0, p_ptr->pac + p_ptr->ptoac, CLA_MISC_HIT)) {
 	    if (!py.flags.sustain_str) {
-		(void)dec_stat(A_STR);
+		(void)dec_stat(A_STR, 10, FALSE);
 		objdes(tmp, t_ptr, TRUE);
 		take_hit(dam, tmp);
 		msg_print("A small dart weakens you!");
@@ -226,7 +224,7 @@ int y, x;
       case 18:			   /* CON Dart */
 	if (test_hit(125, 0, 0, p_ptr->pac + p_ptr->ptoac, CLA_MISC_HIT)) {
 	    if (!py.flags.sustain_con) {
-		(void)dec_stat(A_CON);
+		(void)dec_stat(A_CON, 10, FALSE);
 		objdes(tmp, t_ptr, TRUE);
 		take_hit(dam, tmp);
 		msg_print("A small dart saps your health!");
@@ -1298,7 +1296,7 @@ int y, x;
     if (CH_LOSE_STR & t_ptr->flags) {
 	msg_print("A small needle has pricked you!");
 	if (!py.flags.sustain_str) {
-	    (void)dec_stat(A_STR);
+	    (void)dec_stat(A_STR, 10, FALSE);
 	    take_hit(damroll(1, 4), "a poison needle");
 	    msg_print("You feel weakened!");
 	} else
@@ -1340,8 +1338,9 @@ void
 openobject()
 {
     int                    y, x, i, dir;
+    int                    save_y = char_row, save_x = char_col, nobj;
     int                    flag, no_object;
-    register cave_type    *c_ptr;
+    register cave_type    *c_ptr = NULL;
     register inven_type   *t_ptr;
     register struct misc  *p_ptr;
     register monster_type *m_ptr;
@@ -1351,133 +1350,163 @@ openobject()
 			       target_mode, then turn it off -CFT */
 #endif
 
-    y = char_row;
-    x = char_col;
-#ifdef TARGET
-    target_mode = FALSE;
-#endif
-    if (get_dir(NULL, &dir)) {
-	(void)mmove(dir, &y, &x);
-	c_ptr = &cave[y][x];
-	no_object = FALSE;
-	if (c_ptr->cptr > 1 && c_ptr->tptr != 0 &&
-	    (t_list[c_ptr->tptr].tval == TV_CLOSED_DOOR
-	     || t_list[c_ptr->tptr].tval == TV_CHEST)) {
-	    m_ptr = &m_list[c_ptr->cptr];
-	    if (m_ptr->ml) {
-		if (c_list[m_ptr->mptr].cdefense & UNIQUE)
-		    (void)sprintf(m_name, "%s", c_list[m_ptr->mptr].name);
-		else
-		    (void)sprintf(m_name, "The %s", c_list[m_ptr->mptr].name);
-	    } else
-		(void)strcpy(m_name, "Something");
-	    (void)sprintf(out_val, "%s is in your way!", m_name);
-	    msg_print(out_val);
-	} else if (c_ptr->tptr != 0)
-	/* Closed door		 */
-	    if (t_list[c_ptr->tptr].tval == TV_CLOSED_DOOR) {
-		t_ptr = &t_list[c_ptr->tptr];
-		if (t_ptr->p1 > 0) {
-		    p_ptr = &py.misc;
-		    i = p_ptr->disarm + 2 * todis_adj() + stat_adj(A_INT)
-			+ (class_level_adj[p_ptr->pclass][CLA_DISARM]
-			   * p_ptr->lev / 3);
-	/* give a 1/50 chance of opening anything, anyway -CWS */
-		    if ((i - t_ptr->p1) < 2)
-			i = t_ptr->p1 + 2;
-		    if (py.flags.confused > 0)
-			msg_print("You are too confused to pick the lock.");
-		    else if ((i - t_ptr->p1) > randint(100)) {
-			msg_print("You have picked the lock.");
-			py.misc.exp++;
-			prt_experience();
-			t_ptr->p1 = 0;
-		    } else
-			count_msg_print("You failed to pick the lock.");
-		} else if (t_ptr->p1 < 0)	/* It's stuck	  */
-		    msg_print("It appears to be stuck.");
-		if (t_ptr->p1 == 0) {
-		    invcopy(&t_list[c_ptr->tptr], OBJ_OPEN_DOOR);
-		    c_ptr->fval = CORR_FLOOR;
-		    lite_spot(y, x);
-		    check_view();
-		    command_count = 0;
-		}
+    no_object = TRUE;
+    nobj = 0; /* count the number of doors/chests */
+    for (y = char_row - 1; y <= char_row + 1; y++) {
+	for (x = char_col - 1; x <= char_col + 1; x++) {
+	    if ((y == char_row) && (x == char_col))
+		continue;
+	    c_ptr = &cave[y][x];
+	    if (c_ptr->tptr != 0 &&
+		(t_list[c_ptr->tptr].tval == TV_CLOSED_DOOR
+		 || t_list[c_ptr->tptr].tval == TV_CHEST)) {
+		    nobj++;
+		    save_x = x;
+		    save_y = y;
 	    }
-    /* Open a closed chest.		     */
-	    else if (t_list[c_ptr->tptr].tval == TV_CHEST) {
-		p_ptr = &py.misc;
-		i = p_ptr->disarm + 2 * todis_adj() + stat_adj(A_INT)
-		    + (class_level_adj[p_ptr->pclass][CLA_DISARM] * p_ptr->lev / 3);
-		t_ptr = &t_list[c_ptr->tptr];
-		flag = FALSE;
-		if (CH_LOCKED & t_ptr->flags)
-		    if (py.flags.confused > 0)
-			msg_print("You are too confused to pick the lock.");
-		    else if ((i - (int)t_ptr->level) > randint(100)) {
-			msg_print("You have picked the lock.");
-			flag = TRUE;
-			py.misc.exp += t_ptr->level;
-			prt_experience();
-		    } else
-			count_msg_print("You failed to pick the lock.");
-		else
-		    flag = TRUE;
-		if (flag) {
-		    t_ptr->flags &= ~CH_LOCKED;
-		    t_ptr->name2 = SN_EMPTY;
-		    known2(t_ptr);
-		    t_ptr->cost = 0;
-		}
-		flag = FALSE;
-	    /* Was chest still trapped?	 (Snicker)   */
-		if ((CH_LOCKED & t_ptr->flags) == 0) {
-		    chest_trap(y, x);
-		    if (c_ptr->tptr != 0)
-			flag = TRUE;
-		}
-	    /* Chest treasure is allocated as if a creature   */
-	    /* had been killed.				   */
-		if (flag) {
-		/*
-		 * clear the cursed chest/monster win flag, so that people
-		 * can not win by opening a cursed chest 
-		 */
-		    t_ptr->flags &= ~TR_CURSED;
-
-		/* generate based on level chest was found on - dbd */
-		    object_level = t_ptr->p1;
-
-	        /* but let's not get too crazy with storebought chests -CWS */
-		    if (t_ptr->ident & ID_STOREBOUGHT) {
-			if (object_level > 20)
-			    object_level = 20;
-		    }
-
-		    if (object_level < 0) /* perform some sanity checking -CWS */
-			object_level = 0;
-		    if (object_level > MAX_OBJ_LEVEL)
-			object_level = MAX_OBJ_LEVEL;
-
-		    coin_type = 0;
-		    opening_chest = TRUE; /* don't generate another chest -CWS */
-		    (void)monster_death(y, x, t_list[c_ptr->tptr].flags, 0, 0);
-		    t_list[c_ptr->tptr].flags = 0;
-		    opening_chest = FALSE;
-		}
-	    } else
-		no_object = TRUE;
-	else
-	    no_object = TRUE;
-
-	if (no_object) {
-	    msg_print("I do not see anything you can open there.");
-	    free_turn_flag = TRUE;
 	}
     }
+    if (nobj == 1) { /* only one door/chest */
+	x = save_x;
+	y = save_y;
+	c_ptr = &cave[y][x];
+	no_object = FALSE;
+    } else
+    /* multiple doors/chests */
+    if (nobj > 1) {
 #ifdef TARGET
-    target_mode = temp;
+	target_mode = FALSE;
 #endif
+	if (!get_dir(NULL, &dir)) {
+	    free_turn_flag = TRUE;
+#ifdef TARGET
+	    target_mode = temp;
+#endif
+	    return;
+	}
+	y = char_row;
+	x = char_col;
+	(void)mmove(dir, &y, &x);
+#ifdef TARGET
+	target_mode = temp;
+#endif
+	c_ptr = &cave[y][x];
+	if (c_ptr->tptr != 0 && (t_list[c_ptr->tptr].tval == TV_CLOSED_DOOR ||
+				 t_list[c_ptr->tptr].tval == TV_CHEST))
+	    no_object = FALSE;
+    }
+
+    if (no_object) {
+	msg_print("I do not see anything you can open there.");
+	free_turn_flag = TRUE;
+    } else
+    /* monster on the door/chest */
+    if (c_ptr->cptr > 1) {
+	m_ptr = &m_list[c_ptr->cptr];
+	if (m_ptr->ml) {
+	    if (c_list[m_ptr->mptr].cdefense & UNIQUE)
+		(void)sprintf(m_name, "%s is", c_list[m_ptr->mptr].name);
+	    else if (c_list[m_ptr->mptr].gender == 'p')
+		(void)sprintf(m_name, "The %s are", c_list[m_ptr->mptr].name);
+	    else
+		(void)sprintf(m_name, "The %s is", c_list[m_ptr->mptr].name);
+	} else
+	    (void)strcpy(m_name, "Something is");
+	(void)sprintf(out_val, "%s in your way!", m_name);
+	msg_print(out_val);
+    } else
+    /* Closed door		 */
+    if (t_list[c_ptr->tptr].tval == TV_CLOSED_DOOR) {
+	t_ptr = &t_list[c_ptr->tptr];
+	if (t_ptr->p1 > 0) {
+	    p_ptr = &py.misc;
+	    i = p_ptr->disarm + 2 * todis_adj() + stat_adj(A_INT)
+		+ (class_level_adj[p_ptr->pclass][CLA_DISARM] * p_ptr->lev / 3);
+	/* give a 1/50 chance of opening anything, anyway -CWS */
+	    if ((i - t_ptr->p1) < 2)
+		i = t_ptr->p1 + 2;
+	    if (py.flags.confused > 0)
+		msg_print("You are too confused to pick the lock.");
+	    else if ((i - t_ptr->p1) > randint(100)) {
+		msg_print("You have picked the lock.");
+		py.misc.exp++;
+		prt_experience();
+		t_ptr->p1 = 0;
+	    } else
+		count_msg_print("You failed to pick the lock.");
+	} else if (t_ptr->p1 < 0)	/* It's stuck	  */
+	    msg_print("It appears to be stuck.");
+	if (t_ptr->p1 == 0) {
+	    invcopy(&t_list[c_ptr->tptr], OBJ_OPEN_DOOR);
+	    c_ptr->fval = CORR_FLOOR;
+	    lite_spot(y, x);
+	    check_view();
+	    command_count = 0;
+	}
+    }
+    /* Open a closed chest.		     */
+    else if (t_list[c_ptr->tptr].tval == TV_CHEST) {
+	p_ptr = &py.misc;
+	i = p_ptr->disarm + 2 * todis_adj() + stat_adj(A_INT)
+	    + (class_level_adj[p_ptr->pclass][CLA_DISARM] * p_ptr->lev / 3);
+	t_ptr = &t_list[c_ptr->tptr];
+	flag = FALSE;
+	if (CH_LOCKED & t_ptr->flags)
+	    if (py.flags.confused > 0)
+		msg_print("You are too confused to pick the lock.");
+	    else if ((i - (int)t_ptr->level) > randint(100)) {
+		msg_print("You have picked the lock.");
+		flag = TRUE;
+		py.misc.exp += t_ptr->level;
+		prt_experience();
+	    } else
+		count_msg_print("You failed to pick the lock.");
+	else
+	    flag = TRUE;
+	if (flag) {
+	    t_ptr->flags &= ~CH_LOCKED;
+	    t_ptr->name2 = SN_EMPTY;
+	    known2(t_ptr);
+	    t_ptr->cost = 0;
+	}
+	flag = FALSE;
+	/* Was chest still trapped?	 (Snicker)   */
+	if ((CH_LOCKED & t_ptr->flags) == 0) {
+	    chest_trap(y, x);
+	    if (c_ptr->tptr != 0)
+		flag = TRUE;
+	}
+    /* Chest treasure is allocated as if a creature    */
+    /* had been killed.				   */
+	if (flag) {
+	/*
+	 * clear the cursed chest/monster win flag, so that people
+	 * can not win by opening a cursed chest 
+	 */
+	    t_ptr->flags &= ~TR_CURSED;
+
+	/* generate based on level chest was found on - dbd */
+	    object_level = t_ptr->p1;
+
+	/* but let's not get too crazy with storebought chests -CWS */
+	    if (t_ptr->ident & ID_STOREBOUGHT) {
+		if (object_level > 20)
+		    object_level = 20;
+	    }
+
+	    if (object_level < 0) /* perform some sanity checking -CWS */
+		object_level = 0;
+	    if (object_level > MAX_OBJ_LEVEL)
+		object_level = MAX_OBJ_LEVEL;
+
+	    coin_type = 0;
+	    opening_chest = TRUE; /* don't generate another chest -CWS */
+
+	    (void)monster_death(y, x, t_list[c_ptr->tptr].flags, 0, 0);
+	    t_list[c_ptr->tptr].flags = 0;
+	    opening_chest = FALSE;
+	}
+    }
 }
 
 
@@ -1486,57 +1515,85 @@ void
 closeobject()
 {
     int                    y, x, dir, no_object;
+    int                    save_y = char_row, save_x = char_col, nobj;
     vtype                  out_val, m_name;
-    register cave_type    *c_ptr;
+    register cave_type    *c_ptr = NULL;
     register monster_type *m_ptr;
 #ifdef TARGET
     int temp = target_mode; /* targetting will screw up get_dir, so we save
 			       target_mode, then turn it off -CFT */
 #endif
 
-    y = char_row;
-    x = char_col;
-#ifdef TARGET
-    target_mode = FALSE;
-#endif
-    if (get_dir(NULL, &dir)) {
-	(void)mmove(dir, &y, &x);
-	c_ptr = &cave[y][x];
-	no_object = FALSE;
-	if (c_ptr->tptr != 0)
-	    if (t_list[c_ptr->tptr].tval == TV_OPEN_DOOR)
-		if (c_ptr->cptr == 0)
-		    if (t_list[c_ptr->tptr].p1 == 0) {
-			invcopy(&t_list[c_ptr->tptr], OBJ_CLOSED_DOOR);
-			c_ptr->fval = BLOCKED_FLOOR;
-			lite_spot(y, x);
-		    } else
-			msg_print("The door appears to be broken.");
-		else {
-		    m_ptr = &m_list[c_ptr->cptr];
-		    if (m_ptr->ml) {
-			if (c_list[m_ptr->mptr].cdefense & UNIQUE)
-			    (void)sprintf(m_name, "%s", c_list[m_ptr->mptr].name);
-			else
-			    (void)sprintf(m_name, "The %s", c_list[m_ptr->mptr].name);
-		    } else
-			(void)strcpy(m_name, "Something");
-		    (void)sprintf(out_val, "%s is in your way!", m_name);
-		    msg_print(out_val);
-		}
-	    else
-		no_object = TRUE;
-	else
-	    no_object = TRUE;
-
-	if (no_object) {
-	    msg_print("I do not see anything you can close there.");
-	    free_turn_flag = TRUE;
+    no_object = TRUE;
+    nobj = 0; /* count the number of adjacent open doors */
+    for (y = char_row - 1; y <= char_row + 1; y++) {
+	for (x = char_col - 1; x <= char_col + 1; x++) {
+	    if ((y == char_row) && (x == char_col))
+		continue;
+	    c_ptr = &cave[y][x];
+	    if (c_ptr->tptr != 0 &&
+		(t_list[c_ptr->tptr].tval == TV_OPEN_DOOR)) {
+		    nobj++;
+		    save_x = x;
+		    save_y = y;
+	    }
 	}
     }
+
+    if (nobj == 1) { /* only one door to close */
+	x = save_x;
+	y = save_y;
+	c_ptr = &cave[y][x];
+	no_object = FALSE;
+    } else if (nobj > 1) { /* multiple doors to close */
 #ifdef TARGET
-    target_mode = temp;
+	target_mode = FALSE;
 #endif
+	if (!get_dir(NULL, &dir)) {
+	    free_turn_flag = TRUE;
+#ifdef TARGET
+	    target_mode = temp;
+#endif
+	    return;
+	}
+	y = char_row;
+	x = char_col;
+	(void)mmove(dir, &y, &x);
+#ifdef TARGET
+	target_mode = temp;
+#endif
+	c_ptr = &cave[y][x];
+	if (c_ptr->tptr != 0 && t_list[c_ptr->tptr].tval == TV_OPEN_DOOR)
+	    no_object = FALSE;
+    }
+
+    if (no_object) {
+	msg_print("I do not see anything you can close there.");
+	free_turn_flag = TRUE;
+    } else
+    if (c_ptr->cptr == 0)
+    /* close the door */
+	if (t_list[c_ptr->tptr].p1 == 0) {
+	    invcopy(&t_list[c_ptr->tptr], OBJ_CLOSED_DOOR);
+	    c_ptr->fval = BLOCKED_FLOOR;
+	    lite_spot(y, x);
+	} else
+	    msg_print("The door appears to be broken.");
+    else {
+    /* monster on the door */
+	m_ptr = &m_list[c_ptr->cptr];
+	if (m_ptr->ml) {
+	    if (c_list[m_ptr->mptr].cdefense & UNIQUE)
+		(void)sprintf(m_name, "%s is", c_list[m_ptr->mptr].name);
+	    else if (c_list[m_ptr->mptr].gender == 'p')
+		(void)sprintf(m_name, "The %s are", c_list[m_ptr->mptr].name);
+	    else
+		(void)sprintf(m_name, "The %s is", c_list[m_ptr->mptr].name);
+	} else
+	    (void)strcpy(m_name, "Something is");
+	(void)sprintf(out_val, "%s in your way!", m_name);
+	msg_print(out_val);
+    }
 }
 
 
@@ -1745,110 +1802,149 @@ int dir;
 void 
 disarm_trap()
 {
-    int                 y, x, level, tmp, dir, no_disarm;
-    register int        tot, i;
-    register cave_type *c_ptr;
-    register inven_type *i_ptr;
-    monster_type       *m_ptr;
-    vtype               m_name, out_val;
+    int                    y, x, level, tmp, dir, no_disarm;
+    int                    save_y = char_row, save_x = char_col, save_dir = 5, nobj;
+    register int           tot, i;
+    register cave_type    *c_ptr = NULL;
+    register inven_type   *i_ptr;
+    monster_type          *m_ptr;
+    vtype                  m_name, out_val;
 #ifdef TARGET
     int temp = target_mode; /* targetting will screw up get_dir, so we save
 			       target_mode, then turn it off -CFT */
 #endif
 
-    y = char_row;
-    x = char_col;
-#ifdef TARGET
-    target_mode = FALSE;
-#endif
-    if (get_dir(NULL, &dir)) {
-	(void)mmove(dir, &y, &x);
-	c_ptr = &cave[y][x];
-	no_disarm = FALSE;
-	if (c_ptr->cptr > 1 && c_ptr->tptr != 0 &&
-	    (t_list[c_ptr->tptr].tval == TV_VIS_TRAP
-	     || t_list[c_ptr->tptr].tval == TV_CHEST)) {
-	    m_ptr = &m_list[c_ptr->cptr];
-	    if (m_ptr->ml)
-		(void)sprintf(m_name, "The %s", c_list[m_ptr->mptr].name);
-	    else
-		(void)strcpy(m_name, "Something");
-	    (void)sprintf(out_val, "%s is in your way!", m_name);
-	    msg_print(out_val);
-	} else if (c_ptr->tptr != 0) {
-	    tot = py.misc.disarm + 2 * todis_adj() + stat_adj(A_INT)
-		+ (class_level_adj[py.misc.pclass][CLA_DISARM] * py.misc.lev / 3);
-	    if ((py.flags.blind > 0) || (no_light()))
-		tot = tot / 10;
-	    if (py.flags.confused > 0)
-		tot = tot / 10;
-	    if (py.flags.image > 0)
-		tot = tot / 10;
-	    i_ptr = &t_list[c_ptr->tptr];
-	    i = i_ptr->tval;
-	    level = i_ptr->level;
-	    if (i == TV_VIS_TRAP) {/* Floor trap    */
-		if ((tot + 100 - level) > randint(100)) {
-		    msg_print("You have disarmed the trap.");
-		    py.misc.exp += i_ptr->p1;
-		    (void)delete_object(y, x);
-		/* make sure we move onto the trap even if confused */
-		    tmp = py.flags.confused;
-		    py.flags.confused = 0;
-		    move_char(dir, FALSE);
-		    py.flags.confused = tmp;
-		    prt_experience();
-		}
-	    /* avoid randint(0) call */
-		else if ((tot > 5) && (randint(tot) > 5))
-		    count_msg_print("You failed to disarm the trap.");
-		else {
-		    msg_print("You set the trap off!");
-		/* make sure we move onto the trap even if confused */
-		    tmp = py.flags.confused;
-		    py.flags.confused = 0;
-		    move_char(dir, FALSE);
-		    py.flags.confused += tmp;
-		}
-	    } else if (i == TV_CHEST) {
-		if (!known2_p(i_ptr)) {
-		    msg_print("I don't see a trap.");
-		    free_turn_flag = TRUE;
-		} else if (CH_TRAPPED & i_ptr->flags) {
-		    if ((tot - level) > randint(100)) {
-			i_ptr->flags &= ~CH_TRAPPED;
-			if (CH_LOCKED & i_ptr->flags)
-			    i_ptr->name2 = SN_LOCKED;
-			else
-			    i_ptr->name2 = SN_DISARMED;
-			msg_print("You have disarmed the chest.");
-			known2(i_ptr);
-			py.misc.exp += level;
-			prt_experience();
-		    } else if ((tot > 5) && (randint(tot) > 5))
-			count_msg_print("You failed to disarm the chest.");
-		    else {
-			msg_print("You set a trap off!");
-			known2(i_ptr);
-			chest_trap(y, x);
-		    }
-		} else {
-		    msg_print("The chest was not trapped.");
-		    free_turn_flag = TRUE;
-		}
-	    } else
-		no_disarm = TRUE;
-	} else
-	    no_disarm = TRUE;
-
-	if (no_disarm) {
-	    msg_print("I do not see anything to disarm there.");
-	    free_turn_flag = TRUE;
+    no_disarm = TRUE;
+    nobj = 0; /* count the number of traps/chests */
+    dir = 0;
+    for (y = char_row + 1; y >= char_row - 1; y--) {
+	for (x = char_col - 1; x <= char_col + 1; x++) {
+	    dir++;
+	    if ((y == char_row) && (x == char_col))
+		continue;
+	    c_ptr = &cave[y][x];
+	    if (c_ptr->tptr != 0 &&
+		(t_list[c_ptr->tptr].tval == TV_VIS_TRAP ||
+		 t_list[c_ptr->tptr].tval == TV_CHEST)) {
+		nobj++;
+		save_x = x;
+		save_y = y;
+		save_dir = dir;
+	    }
 	}
     }
+
+    if (nobj == 1) { /* only one trap/chest */
+	x = save_x;
+	y = save_y;
+	c_ptr = &cave[y][x];
+	dir = save_dir;
+	no_disarm = FALSE;
+    } else if (nobj > 1) {	/* multiple traps/chests */
+
 #ifdef TARGET
-    target_mode = temp;
+	target_mode = FALSE;
 #endif
+	if (!get_dir(NULL, &dir)) {
+	    free_turn_flag = TRUE;
+#ifdef TARGET
+	    target_mode = temp;
+#endif
+	    return;
+	}
+	y = char_row;
+	x = char_col;
+	(void)mmove(dir, &y, &x);
+#ifdef TARGET
+	target_mode = temp;
+#endif
+	if (c_ptr->cptr > 1 && c_ptr->tptr != 0 &&
+	    (t_list[c_ptr->tptr].tval == TV_VIS_TRAP
+	     || t_list[c_ptr->tptr].tval == TV_CHEST))
+	    no_disarm = FALSE;
+	else
+	    no_disarm = TRUE;
+    }
+    if (no_disarm) {
+	msg_print("I do not see anything to disarm there.");
+	free_turn_flag = TRUE;
+    } else if (c_ptr->cptr > 1) {	/* monster on trap/chest */
+	m_ptr = &m_list[c_ptr->cptr];
+	if (m_ptr->ml) {
+	    if (c_list[m_ptr->mptr].cdefense & UNIQUE)
+		(void)sprintf(m_name, "%s is", c_list[m_ptr->mptr].name);
+	    else if (c_list[m_ptr->mptr].gender == 'p')
+		(void)sprintf(m_name, "The %s are", c_list[m_ptr->mptr].name);
+	    else
+		(void)sprintf(m_name, "The %s is", c_list[m_ptr->mptr].name);
+	} else
+	    (void)strcpy(m_name, "Something is");
+	(void)sprintf(out_val, "%s in your way!", m_name);
+	msg_print(out_val);
+    } else {
+	/* disarm the trap/chest */
+	tot = py.misc.disarm + 2 * todis_adj() + stat_adj(A_INT)
+	    + (class_level_adj[py.misc.pclass][CLA_DISARM] * py.misc.lev / 3);
+	if ((py.flags.blind > 0) || (no_light()))
+	    tot = tot / 10;
+	if (py.flags.confused > 0)
+	    tot = tot / 10;
+	if (py.flags.image > 0)
+	    tot = tot / 10;
+	i_ptr = &t_list[c_ptr->tptr];
+	i = i_ptr->tval;
+	level = i_ptr->level;
+	if (i == TV_VIS_TRAP) {/* Floor trap    */
+	    if ((tot + 100 - level) > randint(100)) {
+		msg_print("You have disarmed the trap.");
+		py.misc.exp += i_ptr->p1;
+		(void)delete_object(y, x);
+		/* make sure we move onto the trap even if confused */
+		tmp = py.flags.confused;
+		py.flags.confused = 0;
+		move_char(dir, FALSE);
+		py.flags.confused = tmp;
+		prt_experience();
+	    }
+	    /* avoid randint(0) call */
+	    else if ((tot > 5) && (randint(tot) > 5))
+		count_msg_print("You failed to disarm the trap.");
+	    else {
+		msg_print("You set the trap off!");
+		/* make sure we move onto the trap even if confused */
+		tmp = py.flags.confused;
+		py.flags.confused = 0;
+		move_char(dir, FALSE);
+		py.flags.confused += tmp;
+	    }
+	} else if (i == TV_CHEST) {
+	    if (!known2_p(i_ptr)) {
+		msg_print("I don't see a trap.");
+		free_turn_flag = TRUE;
+	    } else if (CH_TRAPPED & i_ptr->flags) {
+		if ((tot - level) > randint(100)) {
+		    i_ptr->flags &= ~CH_TRAPPED;
+		    if (CH_LOCKED & i_ptr->flags)
+			i_ptr->name2 = SN_LOCKED;
+		    else
+			i_ptr->name2 = SN_DISARMED;
+		    msg_print("You have disarmed the chest.");
+		    known2(i_ptr);
+		    py.misc.exp += level;
+		    prt_experience();
+		} else if ((tot > 5) && (randint(tot) > 5))
+		    count_msg_print("You failed to disarm the chest.");
+		else {
+		    msg_print("You set a trap off!");
+		    known2(i_ptr);
+		    chest_trap(y, x);
+		}
+	    } else {
+		msg_print("The chest was not trapped.");
+		free_turn_flag = TRUE;
+	    }
+	}
+    }
 }
 
 
@@ -1929,7 +2025,7 @@ static int map_diag2[] = {2, 1, 0, 4, 3};
 void 
 look()
 {
-    register int        i, abort;
+    register int        i, stop_looking;
     int                 dir, dummy;
 
     if (py.flags.blind > 0)
@@ -1937,15 +2033,15 @@ look()
     else if (py.flags.image > 0)
 	msg_print("You can't believe what you are seeing! It's like a dream!");
     else if (get_alldir("Look which direction? ", &dir)) {
-	abort = FALSE;
+	stop_looking = FALSE;
 	gl_nseen = 0;
 	gl_rock = 0;
 	gl_noquery = FALSE;	   /* Have to set this up for the look_see */
 	if (look_see(0, 0, &dummy))
-	    abort = TRUE;
+	    stop_looking = TRUE;
 	else {
 	    do {
-		abort = FALSE;
+		stop_looking = FALSE;
 		if (dir == 5) {
 		    for (i = 1; i <= 4; i++) {
 			gl_fxx = set_fxx[i];
@@ -1953,13 +2049,13 @@ look()
 			gl_fxy = set_fxy[i];
 			gl_fyy = set_fyy[i];
 			if (look_ray(0, 2 * GRADF - 1, 1)) {
-			    abort = TRUE;
+			    stop_looking = TRUE;
 			    break;
 			}
 			gl_fxy = (-gl_fxy);
 			gl_fyy = (-gl_fyy);
 			if (look_ray(0, 2 * GRADF, 2)) {
-			    abort = TRUE;
+			    stop_looking = TRUE;
 			    break;
 			}
 		    }
@@ -1970,11 +2066,11 @@ look()
 		    gl_fxy = set_fxy[i];
 		    gl_fyy = set_fyy[i];
 		    if (look_ray(0, GRADF, 1))
-			abort = TRUE;
+			stop_looking = TRUE;
 		    else {
 			gl_fxy = (-gl_fxy);
 			gl_fyy = (-gl_fyy);
-			abort = look_ray(0, GRADF, 2);
+			stop_looking = look_ray(0, GRADF, 2);
 		    }
 		} else {
 		    i = map_diag1[dir >> 1];
@@ -1983,19 +2079,19 @@ look()
 		    gl_fxy = (-set_fxy[i]);
 		    gl_fyy = (-set_fyy[i]);
 		    if (look_ray(1, 2 * GRADF, GRADF))
-			abort = TRUE;
+			stop_looking = TRUE;
 		    else {
 			i = map_diag2[dir >> 1];
 			gl_fxx = set_fxx[i];
 			gl_fyx = set_fyx[i];
 			gl_fxy = set_fxy[i];
 			gl_fyy = set_fyy[i];
-			abort = look_ray(1, 2 * GRADF - 1, GRADF);
+			stop_looking = look_ray(1, 2 * GRADF - 1, GRADF);
 		    }
 		}
 	    }
-	    while (abort == FALSE && highlight_seams && (++gl_rock < 2));
-	    if (abort)
+	    while (stop_looking == FALSE && highlight_seams && (++gl_rock < 2));
+	    if (stop_looking)
 		msg_print("--Aborting look--");
 	    else {
 		if (gl_nseen) {
@@ -2114,7 +2210,7 @@ register int        x, y;
 int                *transparent;
 {
     const char         *dstring,*string;
-    char               query = 'a';
+    char               query = 'a', sex;
     register cave_type *c_ptr;
     register int        j;
     bigvtype            out_val, tmp_str;
@@ -2137,23 +2233,20 @@ int                *transparent;
     c_ptr = &cave[y][x];
     *transparent = c_ptr->fval <= MAX_OPEN_SPACE;
     if (gl_noquery)
-	return FALSE;		   /* Don't look at a direct line of sight. A
-				    * hack. */
+	return FALSE;	   /* Don't look at a direct line of sight.  A hack. */
     out_val[0] = 0;
     if (gl_rock == 0 && c_ptr->cptr > 1 && m_list[c_ptr->cptr].ml) {
 	j = m_list[c_ptr->cptr].mptr;
-	if (c_list[j].cdefense & UNIQUE)
-	    (void)sprintf(out_val, "%s %s (%s).  [(r)ecall]",
-			  dstring,
-			  c_list[j].name,
-			  look_mon_desc((int)c_ptr->cptr));
-	else
-	    (void)sprintf(out_val, "%s %s %s (%s).  [(r)ecall]",
-			  dstring,
-			  (is_a_vowel(c_list[j].name[0]) ? "an" : "a"),
-			  c_list[j].name,
-			  look_mon_desc((int)c_ptr->cptr));
-	dstring = "It is on";
+	sex = c_list[j].gender;
+	(void)sprintf(out_val, "%s%s %s (%s).  [(r)ecall]",
+		      dstring,
+		      ((c_list[j].cdefense & UNIQUE) || (sex == 'p')) ? "" :
+		      is_a_vowel(c_list[j].name[0]) ? " an" : " a",
+		      c_list[j].name,
+		      look_mon_desc((int)c_ptr->cptr));
+	dstring = ( sex == 'm' ? "He is on" : sex == 'f' ? "She is on" :
+		    sex == 'p' ? "They are on" : "It is on" );
+
 	prt(out_val, 0, 0);
 	move_cursor_relative(y, x);
 	query = inkey();
@@ -2242,6 +2335,7 @@ facts(i_ptr, tbth, tpth, tdam, tdis, thits)
     int                 *tbth, *tpth, *tdam, *tdis, *thits;
 {
     register int        tmp_weight;
+    int                 tmp_tohit; /* Just a dummy -EAM */
 
     if (i_ptr->weight < 1)
 	tmp_weight = 1;
@@ -2298,6 +2392,9 @@ facts(i_ptr, tbth, tpth, tdam, tdis, thits)
 		*tdam += inventory[INVEN_WIELD].todam;
 		*tdam = *tdam * 2;
 		*tdis = 25;
+		if (py.misc.pclass == 4)
+		    *thits = attack_blows((int)inventory[INVEN_WIELD].weight,
+					  &tmp_tohit) / 2;
 	    }
 	    break;
 	  case 2:
@@ -2307,15 +2404,21 @@ facts(i_ptr, tbth, tpth, tdam, tdis, thits)
 		*tdam += inventory[INVEN_WIELD].todam;
 		*tdam = *tdam * 3;
 		*tdis = 30;
+		if (py.misc.pclass == 4)
+		    *thits = attack_blows((int)inventory[INVEN_WIELD].weight,
+					  &tmp_tohit) / 2;
 	    }
 	    break;
 	  case 3:
-	    if (i_ptr->tval == TV_ARROW){   /* C Bow, BARD, L bow of M and Arrow*/
+	    if (i_ptr->tval == TV_ARROW) {   /* C Bow, BARD, L bow of M and Arrow*/
 		*tbth = py.misc.bthb;
 		*tpth += 2 * inventory[INVEN_WIELD].tohit;
 		*tdam += inventory[INVEN_WIELD].todam;
 		*tdam = *tdam * 4;
 		*tdis = 35;
+		if (py.misc.pclass == 4) 
+		    *thits = attack_blows((int)inventory[INVEN_WIELD].weight,
+					  &tmp_tohit) / 2;
 	    }
 	    break;
 	  case 4:
@@ -2325,6 +2428,9 @@ facts(i_ptr, tbth, tpth, tdam, tdis, thits)
 		*tdam += inventory[INVEN_WIELD].todam;
 		*tdam = *tdam * 5;
 		*tdis = 35;
+		if (py.misc.pclass == 4)
+		    *thits = attack_blows((int)inventory[INVEN_WIELD].weight,
+					  &tmp_tohit) / 2;
 	    }
 	    break;	    
 	  case 10:
@@ -2346,7 +2452,7 @@ facts(i_ptr, tbth, tpth, tdam, tdis, thits)
 	    }
 	    break;
 	  case 12:
-	    if (i_ptr->tval == TV_BOLT){    /* H xbow of M and Bolt*/
+	    if (i_ptr->tval == TV_BOLT) {    /* H xbow of M and Bolt*/
 		*tbth = py.misc.bthb;
 		*tpth += 2 * inventory[INVEN_WIELD].tohit;
 		*tdam += inventory[INVEN_WIELD].todam;
@@ -2356,6 +2462,11 @@ facts(i_ptr, tbth, tpth, tdam, tdis, thits)
 	    break;
 	    
 	}
+
+    if (*thits < 1)
+	*thits = 1;
+    if (strstr("Crossbow", object_list[inventory[INVEN_WIELD].index].name))
+	*thits = 1;
 }
 
 
@@ -2483,48 +2594,52 @@ throw_object()
 	free_turn_flag = TRUE;
     } else if (get_item(&item_val, "Fire/Throw which one?", 0, inven_ctr - 1, 0)) {
 	inven_type *t = &inventory[item_val];
-	
-	if ((t->tval == TV_FLASK) || (t->tval == TV_SLING_AMMO) ||
-	    (t->tval == TV_ARROW) || (t->tval == TV_BOLT) ||
-	    (t->tval == TV_SPIKE) || (t->tval == TV_MISC))
-	    ok_throw = TRUE;
-	else if (((t->tval == TV_FOOD) || (t->tval == TV_POTION1) ||
-		  (t->tval == TV_POTION2)) && known1_p(t) &&
-		 /* almost all potions do 1d1 damage when thrown.  I want the code
-		    to ask before throwing away potions of DEX, *Healing*, etc.
-		    This also means it will ask before throwing potions of slow
-		    poison, and other low value items that the player is likely to
-		    not care about.  This code will mean that mushrooms/molds of
-		    unhealth, potions of detonations and death are the only
-		    always-throwable food/potions.  (plus known bad ones, in a
-		    later test...) -CFT */
-		 (t->damage[0] > 1) && (t->damage[1] > 1))
-	    ok_throw = TRUE; /* if it's a mushroom or potion that does
-                                damage when thrown... */
-	else if (!known2_p(t) && (t->ident & ID_DAMD))
-	    ok_throw = TRUE;  /* Not IDed, but user knows it's cursed... */
-	else if ((t->tval >= TV_MIN_WEAR) && (t->tval <= TV_MAX_WEAR) &&
-		 (t->flags & TR_CURSED) && known2_p(t))
-	    ok_throw = TRUE; /* if user wants to throw cursed, let him */
-	else if ((object_list[t->index].cost <= 0) && known1_p(t) &&
-		 !(known2_p(t) && (t->cost > 0)))
-	    ok_throw = TRUE;
-	else if ((t->cost <= 0) && known2_p(t))
-	    ok_throw = TRUE; /* it's junk, let him throw it */
-	else if ((t->tval >= TV_HAFTED) &&
-		 (t->tval <= TV_DIGGING) && !(t->name2))
-	    ok_throw = TRUE; /* non ego/art weapons are okay to just throw, since
-				they are damaging (Moral of story: wield your weapon
-				if you're worried that you might throw it away!) */
-	else { /* otherwise double-check with user before throwing -CFT */
-	    objdes(tmp_str, t, TRUE);
-	    sprintf(out_val, "Really throw %s?", tmp_str);
-	    ok_throw = get_check(out_val);
+	if (always_throw) { ok_throw = TRUE; }
+	else {
+	    if ((t->tval == TV_FLASK) || (t->tval == TV_SLING_AMMO) ||
+		(t->tval == TV_ARROW) || (t->tval == TV_BOLT) ||
+		(t->tval == TV_SPIKE) || (t->tval == TV_MISC))
+		ok_throw = TRUE;
+	    else if (((t->tval == TV_FOOD) || (t->tval == TV_POTION1) ||
+		      (t->tval == TV_POTION2)) && known1_p(t) &&
+		     /* almost all potions do 1d1 damage when thrown.  I want the code
+			to ask before throwing away potions of DEX, *Healing*, etc.
+			This also means it will ask before throwing potions of slow
+			poison, and other low value items that the player is likely to
+			not care about.  This code will mean that mushrooms/molds of
+			unhealth, potions of detonations and death are the only
+			always-throwable food/potions.  (plus known bad ones, in a
+			later test...) -CFT */
+		     (t->damage[0] > 1) && (t->damage[1] > 1))
+		ok_throw = TRUE; /* if it's a mushroom or potion that does
+				    damage when thrown... */
+	    else if (!known2_p(t) && (t->ident & ID_DAMD))
+		ok_throw = TRUE;  /* Not IDed, but user knows it's cursed... */
+	    else if ((t->tval >= TV_MIN_WEAR) && (t->tval <= TV_MAX_WEAR) &&
+		     (t->flags & TR_CURSED) && known2_p(t))
+		ok_throw = TRUE; /* if user wants to throw cursed, let him */
+	    else if ((object_list[t->index].cost <= 0) && known1_p(t) &&
+		     !(known2_p(t) && (t->cost > 0)))
+		ok_throw = TRUE;
+	    else if ((t->cost <= 0) && known2_p(t))
+		ok_throw = TRUE; /* it's junk, let him throw it */
+	    else if ((t->tval >= TV_HAFTED) &&
+		     (t->tval <= TV_DIGGING) && !(t->name2))
+		ok_throw = TRUE; /* non ego/art weapons are okay to just throw, since
+				    they are damaging (Moral of story: wield your weapon
+				    if you're worried that you might throw it away!) */
+	    else { /* otherwise double-check with user before throwing -CFT */
+		objdes(tmp_str, t, TRUE);
+		sprintf(out_val, "Really throw %s?", tmp_str);
+		ok_throw = get_check(out_val);
+	    }
 	}
     } /* if selected an item to throw */
 
-    if (ok_throw) { /* can only be true if selected item, and it either looked
-		     * okay, or user said yes... */
+    if (!ok_throw)
+	free_turn_flag = TRUE;
+    else { /* can only be true if selected item, and it either looked
+	    * okay, or user said yes... */
 	if (get_dir(NULL, &dir)) {
 	    desc_remain(item_val);
 	    if (py.flags.confused > 0) {
@@ -2915,21 +3030,22 @@ int mnum;
 void
 target()
 {
-    int monptr,exit,exit2;
+    int monptr,stop,stop2;
     char query;
     vtype desc;
 
-    exit = FALSE;
-    exit2 = FALSE;
+    stop = FALSE;
+    stop2 = FALSE;
     if (py.flags.blind > 0)
 	msg_print("You can't see anything to target!");
     /* Check monsters first */
     else {
 	target_mode = FALSE;
-	for (monptr = 0; (monptr<mfptr) && (!exit); monptr++) {
-	    if (m_list[monptr].cdis<MAX_SIGHT) {
-		if ((m_list[monptr].ml)&&
-		    (los(char_row,char_col,m_list[monptr].fy,m_list[monptr].fx))) {
+	for (monptr = 0; (monptr<mfptr) && (!stop); monptr++) {
+	    if (m_list[monptr].cdis < MAX_SIGHT) {
+		if ((m_list[monptr].ml) &&
+		    (los(char_row,char_col,m_list[monptr].fy,m_list[monptr].fx)) &&
+		    (c_list[m_list[monptr].mptr].cchar!='.')) {
 		    move_cursor_relative(m_list[monptr].fy,m_list[monptr].fx);
 		    (void) sprintf(desc, "%s [(r)ecall] [(t)arget] [(l)ocation] [ESC quits]",
 				   c_list[m_list[monptr].mptr].name);
@@ -2945,8 +3061,8 @@ target()
 		    }
 		    switch (query) {
 		    case ESCAPE:
-			exit = TRUE;
-			exit2 = TRUE;
+			stop = TRUE;
+			stop2 = TRUE;
 			break;
 		    case '.':	/* for NetHack players, '.' is used to select a target,
 				   so I'm changing this... -CFT */
@@ -2955,20 +3071,20 @@ target()
 			target_mon  = monptr;
 			target_row  = m_list[monptr].fy;
 			target_col  = m_list[monptr].fx;
-			exit2 = TRUE;
+			stop2 = TRUE;
 		    case 'l': case'L':
-			exit = TRUE;
+			stop = TRUE;
 		    default:
 			break;
 		    }
 		}
 	    }
 	}
-	if (exit2 == FALSE) {
+	if (stop2 == FALSE) {
 	    prt("Use cursor to designate target. [(t)arget]",0,0);
 	    target_row = char_row;
 	    target_col = char_col;
-	    for (exit = FALSE; exit==FALSE ;) {
+	    for (stop = FALSE; stop==FALSE ;) {
 		move_cursor_relative(target_row, target_col);
 		query=inkey();
 		if (rogue_like_commands==FALSE) {
@@ -3007,7 +3123,7 @@ target()
 		case ESCAPE:
 		    case'q':
 		case 'Q':
-		    exit = TRUE;
+		    stop = TRUE;
 		    break;
 		case '.':	/* for NetHack players, '.' is used to select a target,
 				   so I'm changing this... -CFT */
@@ -3024,7 +3140,7 @@ target()
 		    else {
 			target_mode = TRUE;
 			target_mon  = MAX_MALLOC;
-			exit = TRUE;
+			stop = TRUE;
 		    }
 		    break;
 		case 'b':
