@@ -8,11 +8,8 @@
  * included in all such copies. 
  */
 
-#include "constant.h"
+#include "angband.h"
 #include "monster.h"
-#include "config.h"
-#include "types.h"
-#include "externs.h"
 
 #ifdef USG
 #include <string.h>
